#!/bin/bash
# Run the Docker tests for the SDP
# Note that this file is expecting to be mapped into the root of the workspace
# and with the sdp directory in the same root.
# So workspace view should look something like:
#    View:
#        //guest/perforce_software/sdp/main/... //myws.sdp/sdp/...
#        //guest/perforce_software/sdp/main/test/* //myws.sdp/*

# Perforce version being tested
P4VER=16.1

oses=""

# Allow the specific platform to be specified via parameter
if [ ,"$1" = ,"ubuntu" ] ; then
	oses="ubuntu"
elif [ ,"$1" = ,"centos" ] ; then
	oses="centos6"
elif [ ,"$1" = ,"centos6" ] ; then
	oses="centos6"
elif [ ,"$1" = ,"centos7" ] ; then
	oses="centos7"
else
	oses="ubuntu centos6 centos7"
	oses="centos6"
fi

echo Building SDP docker containers
# docker build --rm=true -t=ansible-test -f docker/Dockerfile.ansible ./docker
for os in $oses
do
	docker_dir=./docker
	dockerfile_base=${docker_dir}/Dockerfile.${os}.base
	dockerfile_sdp=${docker_dir}/Dockerfile.${os}.sdp
	# Build the base Docker for the OS, and then the SDP variant on top
	docker build --rm=true -t=${os}-base -f ${dockerfile_base} ${docker_dir}
	docker build --rm=true -t=${os}-sdp -f ${dockerfile_sdp} ${docker_dir}
done
